@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Shishi; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
@@ -120,7 +120,6 @@
 #include "xvasprintf.h"
 #include "base64.h"
 #include "getdate.h"
-#include "getline.h"
 #include "strtok_r.h"
 #include "time_r.h"
 #include "timegm.h"
